/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.auth;

import java.util.concurrent.ConcurrentHashMap;
import com.openexchange.crypto.CryptoType;

/**
 * {@link AuthenticationServiceRegistryImpl} Registry of {@link AuthenticationService} that can handle an authentication
 * against a crypto type keys.
 *
 * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
 * @since v2.10.7
 */
public class AuthenticationServiceRegistryImpl implements AuthenticationServiceRegistry {

    private final ConcurrentHashMap<CryptoType.PROTOCOL, AuthenticationService> authServices = new ConcurrentHashMap<>();

    /**
     * Registers a {@link AuthenticationService} to the registry
     *
     * @param authenticationService The {@link AuthenticationService} to register
     */
    public void registerAuthenticationService(AuthenticationService authenticationService) {
        this.authServices.put(authenticationService.getCryptoType(), authenticationService);
    }

    /**
     * Removes a registered {@link AuthenticationService} from the registry
     *
     * @param authenticationService The {@link AuthenticationService} to remove from the registry
     */
    public void unregisterAuthenticationService(AuthenticationService authenticationService) {
        this.authServices.remove(authenticationService.getCryptoType());
    }

    @Override
    public AuthenticationService getAuthenticationService(CryptoType.PROTOCOL type) {
        return this.authServices.get(type);
    }
}
